@@ -26,6 +26,8 @@ from tomsup.plot import (
     plot_heatmap,
 )
 
+from wasabi import msg
+
 
 ###################
 # ___ AGENT ___
@@ -545,7 +547,10 @@ class TOM(Agent):
             params["bias"] = bias
 
         self.params = params
-        self.internal = init_k_tom(params, level, priors=init_states)
+        if init_states == "default":
+            self.internal = init_k_tom(params, level, priors=init_states)
+        else:
+            self.internal = init_states
         self.__kwargs = kwargs
 
         super().__init__(**kwargs)
@@ -556,6 +561,7 @@ class TOM(Agent):
             "b_temp": b_temp,
             "bias": bias,
             "dilution": dilution,
+            "init_states": self.internal,
             **kwargs,
         }
 
@@ -606,7 +612,7 @@ class TOM(Agent):
             Optional[float]: The bias of the agent
         """
         if self.bias is None:
-            print("TOM does not have a bias.")
+            msg.warn("TOM does not have a bias.")
         return self.bias
 
     def get_dilution(self) -> Optional[float]:
@@ -614,8 +620,8 @@ class TOM(Agent):
         Returns:
             Optional[float]: The dilution of the agent
         """
-        if self.get_dilution is None:
-            print("TOM does not have a dilution parameter.")
+        if self.dilution is None:
+            msg.warn("TOM does not have a dilution parameter.")
         return self.dilution
 
     def get_level(self) -> float:
@@ -638,6 +644,7 @@ class TOM(Agent):
             internal_states (dict): The desired internal states of the agent.
         """
         self.internal = internal_states
+        self._start_params["init_states"] = self.internal
 
     def get_parameters(self) -> dict:
         """
@@ -937,7 +944,7 @@ class AgentGroup:
         result = []
         for pair in self.pairing:
             if verbose:
-                print(
+                msg.info(
                     f"Currently the pair, {pair}, is competing for {n_sim} \
                         simulations, each containg {n_rounds} rounds."
                 )
@@ -958,7 +965,7 @@ class AgentGroup:
             result.append(res)
 
         if verbose:
-            print("Simulation complete")
+            msg.good("Simulation complete")
 
         self.__df = ResultsDf(pd.concat(result))  # concatenate into one df
 
@@ -1335,7 +1342,7 @@ def compete(
 
         def __compete(sim):
             if verbose:
-                print(f"\tRunning simulation {sim+1} out of {n_sim}")
+                msg.info(f"\tRunning simulation {sim+1} out of {n_sim}")
 
             res = compete(
                 agent_0,
